import { IChangedArgs } from '@jupyterlab/coreutils';
import { JSONObject } from '@lumino/coreutils';
import { Message } from '@lumino/messaging';
import { ISignal } from '@lumino/signaling';
import { Widget } from '@lumino/widgets';
import { CommandRegistry } from '@lumino/commands';
/**
 * A widget for hosting Dask cluster management.
 */
export declare class DaskClusterManager extends Widget {
    /**
     * Create a new Dask cluster manager.
     */
    constructor(options: DaskClusterManager.IOptions);
    /**
     * The currently selected cluster, or undefined if there is none.
     */
    get activeCluster(): IClusterModel | undefined;
    /**
     * Set an active cluster by id.
     */
    setActiveCluster(id: string): void;
    /**
     * A signal that is emitted when an active cluster changes.
     */
    get activeClusterChanged(): ISignal<this, IChangedArgs<IClusterModel | undefined>>;
    /**
     * Whether the cluster manager is ready to launch a cluster
     */
    get isReady(): boolean;
    /**
     * Get the current clusters known to the manager.
     */
    get clusters(): IClusterModel[];
    /**
     * Refresh the current list of clusters.
     */
    refresh(): Promise<void>;
    /**
     * Start a new cluster.
     */
    start(): Promise<IClusterModel>;
    /**
     * Stop a cluster by ID.
     */
    stop(id: string): Promise<void>;
    /**
     * Scale a cluster by ID.
     */
    scale(id: string): Promise<IClusterModel>;
    /**
     * Dispose of the cluster manager.
     */
    dispose(): void;
    /**
     * Handle an update request.
     */
    protected onUpdateRequest(msg: Message): void;
    /**
     * Rerender after showing.
     */
    protected onAfterShow(msg: Message): void;
    /**
     * Handle `after-attach` messages for the widget.
     */
    protected onAfterAttach(msg: Message): void;
    /**
     * Handle `before-detach` messages for the widget.
     */
    protected onBeforeDetach(msg: Message): void;
    /**
     * Handle the DOM events for the directory listing.
     *
     * @param event - The DOM event sent to the widget.
     *
     * #### Notes
     * This method implements the DOM `EventListener` interface and is
     * called in response to events on the panel's DOM node. It should
     * not be called directly by user code.
     */
    handleEvent(event: Event): void;
    /**
     * Handle `mousedown` events for the widget.
     */
    private _evtMouseDown;
    /**
     * Handle the `'mouseup'` event on the document.
     */
    private _evtMouseUp;
    /**
     * Handle the `'mousemove'` event for the widget.
     */
    private _evtMouseMove;
    /**
     * Start a drag event.
     */
    private _startDrag;
    /**
     * Launch a new cluster on the server.
     */
    private _launchCluster;
    /**
     * Refresh the list of clusters on the server.
     */
    private _updateClusterList;
    /**
     * Stop a cluster by its id.
     */
    private _stopById;
    /**
     * Scale a cluster by its id.
     */
    private _scaleById;
    private _findCluster;
    private _drag;
    private _dragData;
    private _clusterListing;
    private _clusters;
    private _activeCluster;
    private _setActiveById;
    private _injectClientCodeForCluster;
    private _getClientCodeForCluster;
    private _poll;
    private _serverSettings;
    private _activeClusterChanged;
    private _serverErrorShown;
    private _isReady;
    private _registry;
    private _launchClusterId;
}
/**
 * A namespace for DasClusterManager statics.
 */
export declare namespace DaskClusterManager {
    /**
     * Options for the constructor.
     */
    interface IOptions {
        /**
         * Registry of all commands
         */
        registry: CommandRegistry;
        /**
         * The launchCluster command ID.
         */
        launchClusterId: string;
        /**
         * A callback to set the dashboard url.
         */
        setDashboardUrl: (url: string) => void;
        /**
         * A callback to inject client connection cdoe.
         */
        injectClientCodeForCluster: (model: IClusterModel) => void;
        /**
         * A callback to get client code for a cluster.
         */
        getClientCodeForCluster: (model: IClusterModel) => string;
    }
}
/**
 * Props for the cluster listing component.
 */
export interface IClusterListingProps {
    /**
     * A list of dashboard items to render.
     */
    clusters: IClusterModel[];
    /**
     * The id of the active cluster.
     */
    activeClusterId: string;
    /**
     * A function for stopping a cluster by ID.
     */
    stopById: (id: string) => Promise<void>;
    /**
     * Scale a cluster by id.
     */
    scaleById: (id: string) => Promise<IClusterModel>;
    /**
     * A callback to set the active cluster by id.
     */
    setActiveById: (id: string) => void;
    /**
     * A callback to inject client code for a cluster.
     */
    injectClientCodeForCluster: (model: IClusterModel) => void;
}
/**
 * Props for the cluster listing component.
 */
export interface IClusterListingItemProps {
    /**
     * A cluster model to render.
     */
    cluster: IClusterModel;
    /**
     * Whether the cluster is currently active (i.e., if
     * it is being displayed in the dashboard).
     */
    isActive: boolean;
    /**
     * A function for scaling the cluster.
     */
    scale: () => Promise<IClusterModel>;
    /**
     * A function for stopping the cluster.
     */
    stop: () => Promise<void>;
    /**
     * A callback function to set the active cluster.
     */
    setActive: () => void;
    /**
     * A callback to inject client code into an editor.
     */
    injectClientCode: () => void;
}
/**
 * An interface for a JSON-serializable representation of a cluster.
 */
export interface IClusterModel extends JSONObject {
    /**
     * A unique string ID for the cluster.
     */
    id: string;
    /**
     * A display name for the cluster.
     */
    name: string;
    /**
     * A URI for the dask scheduler.
     */
    scheduler_address: string;
    /**
     * A URL for the Dask dashboard.
     */
    dashboard_link: string;
    /**
     * Total number of cores used by the cluster.
     */
    cores: number;
    /**
     * Total memory used by the cluster, as a human-readable string.
     */
    memory: string;
    /**
     * The number of workers for the cluster.
     */
    workers: number;
    /**
     * If adaptive is enabled for the cluster, this contains an object
     * with the minimum and maximum number of workers. Otherwise it is `null`.
     */
    adapt: null | {
        minimum: number;
        maximum: number;
    };
}
